@@ -1,12 +1,11 @@
 from __future__ import annotations
 
-import copy
 import typing
 
 from .. import spec
 
 
-def get_base_units() -> dict[str, int]:
+def get_base_units() -> typing.Mapping[str, int]:
     """return mapping {label: seconds} for standard base units of time"""
     return {
         '1s': 1,
@@ -19,7 +18,7 @@ def get_base_units() -> dict[str, int]:
     }
 
 
-def get_singular_unit_labels() -> dict[spec.SingularTimeUnit, str]:
+def get_singular_unit_labels() -> typing.Mapping[spec.SingularTimeUnit, str]:
     """return mapping {english_name: TimelengthLabel} for singular base units"""
     return {
         'second': '1s',
@@ -32,7 +31,7 @@ def get_singular_unit_labels() -> dict[spec.SingularTimeUnit, str]:
     }
 
 
-def get_plural_unit_labels() -> dict[spec.PluralTimeUnit, str]:
+def get_plural_unit_labels() -> typing.Mapping[spec.PluralTimeUnit, str]:
     """return mapping {english_name: TimelengthLabel} for plural base units"""
     return {
         'seconds': '1s',
@@ -45,20 +44,20 @@ def get_plural_unit_labels() -> dict[spec.PluralTimeUnit, str]:
     }
 
 
-def get_unit_labels() -> dict[str, str]:
+def get_unit_labels() -> typing.Mapping[str, str]:
     """return mapping of singular and plural unit labels"""
     return dict(
-        typing.cast(dict[str, str], get_singular_unit_labels()),
-        **typing.cast(dict[str, str], get_plural_unit_labels())
+        typing.cast(typing.Mapping[str, str], get_singular_unit_labels()),
+        **typing.cast(typing.Mapping[str, str], get_plural_unit_labels())
     )
 
 
-def unit_letters_to_names() -> dict[str, spec.SingularTimeUnit]:
+def unit_letters_to_names() -> typing.Mapping[str, spec.SingularTimeUnit]:
     """return mapping {TimelengthLabel: english_name} for singular base units"""
     return {v[-1]: k for k, v in get_singular_unit_labels().items()}
 
 
-def datetime_singular_unit_labels() -> dict[spec.DatetimeUnit, str]:
+def datetime_singular_unit_labels() -> typing.Mapping[spec.DatetimeUnit, str]:
     """return mapping {english_name: TimelengthLabel} for singular base units"""
     return {
         'second': '1s',
@@ -70,11 +69,11 @@ def datetime_singular_unit_labels() -> dict[spec.DatetimeUnit, str]:
     }
 
 
-def datetime_unit_letters_to_names() -> dict[str, spec.DatetimeUnit]:
+def datetime_unit_letters_to_names() -> typing.Mapping[str, spec.DatetimeUnit]:
     return {v[-1]: k for k, v in datetime_singular_unit_labels().items()}
 
 
-def get_english_to_pandas_units() -> dict[str, str]:
+def get_english_to_pandas_units() -> typing.Mapping[str, str]:
     # https://pandas.pydata.org/pandas-docs/stable/user_guide/timeseries.html#timeseries-offset-aliases
     return {
         'year': 'YS',
@@ -90,6 +89,5 @@ def get_english_to_pandas_units() -> dict[str, str]:
     }
 
 
-def get_pandas_unit_to_english() -> dict[str, str]:
+def get_pandas_unit_to_english() -> typing.Mapping[str, str]:
     return {v: k for k, v in get_english_to_pandas_units().items()}
-
